@@ -47,13 +47,13 @@ namespace Kwave
 	SampleRatePlugin(QObject *parent, const QVariantList &args);
 
 	/** Destructor */
-	virtual ~SampleRatePlugin();
+        virtual ~SampleRatePlugin() Q_DECL_OVERRIDE;
 
 	/**
 	 * changes the sample rate
 	 * @param params list of strings with parameters
 	 */
-	void run(QStringList params) Q_DECL_OVERRIDE;
+        virtual void run(QStringList params) Q_DECL_OVERRIDE;
 
     protected:
 
